Return the prose produced by [margot_plot()], using the same estimates, intervals, ordering and transformation metadata as its figure and table.
Arguments
- .data
A combined estimate table accepted by [margot_plot()].
- ...
Additional arguments to [margot_plot()], including ordering, labels, multiplicity adjustment and plotting options.
- scale_info
Outcome transformation metadata accepted by [margot_plot()]. Supply the constants used during preparation when reporting standardised outcomes in measurement units.