Plot a policy-tree branching decision tree
Source:R/margot_policy_tree_reporting.R
margot_plot_policy_decision_tree.RdThin, explicit wrapper around margot_plot_decision_tree().
Use this helper when the intended artefact is the branching assignment rule.
Arguments
- result_object
A list returned by
margot_causal_forest()or a compatible policy-tree workflow object.- model_name
Character scalar naming the model to plot, with or without the
model_prefix.- ...
Arguments passed to
margot_plot_decision_tree().