Plot policy-tree projections of evaluation points
Source:R/margot_policy_tree_reporting.R
margot_plot_policy_projection.RdThin, explicit wrapper around margot_plot_policy_tree().
Use this helper when the intended artefact is the point/projection plot that shows
observations relative to the selected policy-tree splits.
Arguments
- result_object
A list returned by
margot_causal_forest()or a compatible policy-tree workflow object.- model_name
Character scalar naming the model to plot, with or without the
model_prefix.- ...
Arguments passed to
margot_plot_policy_tree().